You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by fm...@apache.org on 2008/03/14 15:49:37 UTC

svn commit: r637120 - /incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java

Author: fmeschbe
Date: Fri Mar 14 07:49:35 2008
New Revision: 637120

URL: http://svn.apache.org/viewvc?rev=637120&view=rev
Log:
SLING-334 rename request parameter used to force the authentication prompt

Modified:
    incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java

Modified: incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java
URL: http://svn.apache.org/viewvc/incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java?rev=637120&r1=637119&r2=637120&view=diff
==============================================================================
--- incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java (original)
+++ incubator/sling/trunk/sling/httpauth/src/main/java/org/apache/sling/httpauth/impl/AuthorizationHeaderAuthenticationHandler.java Fri Mar 14 07:49:35 2008
@@ -38,7 +38,7 @@
  * the authorization steps based on the Authorization header of the HTTP
  * request. This authenticator should eventually support both BASIC and DIGEST
  * authentication methods.
- *
+ * 
  * @scr.component immediate="false" label="%auth.http.name"
  *                description="%auth.http.description"
  * @scr.property name="service.description" value="HTTP Header Authentication Handler"
@@ -54,14 +54,14 @@
     public static final String PAR_REALM_NAME = "auth.http.realm";
 
     /**
      * The request parameter causing a 401/UNAUTHORIZED status to be sent back in
      * the {@link #authenticate(HttpServletRequest, HttpServletResponse)} method
      * if no credentials are present in the request (value is
      * "X-Sling-Request-Login").
      *
      * @see #authenticate(HttpServletRequest, HttpServletResponse)
      */
-    static final String REQUEST_LOGIN_PARAMETER = "X-Sling-Request-Login";
+    static final String REQUEST_LOGIN_PARAMETER = "sling:authRequestLogin";
 
     /**
      * The special user, whose credentials are always ignored to enable logging
@@ -119,7 +119,7 @@
      * the request may be for an included servlet, in which case the values for
      * some URI specific values are contained in javax.servlet.include.* request
      * attributes.
-     *
+     * 
      * @param request The request object containing the information for the
      *            authentication.
      * @param response The response object which may be used to send the
@@ -159,7 +159,7 @@
      * authentication with the <code>Basic</code> scheme and the configured
      * realm name. If the response is already committed, an error message is
      * logged but the 401 status is not sent.
-     *
+     * 
      * @param request The request object
      * @param response The response object to which to send the request
      * @return <code>true</code> is always returned by this handler
@@ -54,14 +54,14 @@
 
     /**
-     * The request parameter causing a 401/UNAUTHORIZED status to be sent back in
-     * the {@link #authenticate(HttpServletRequest, HttpServletResponse)} method
-     * if no credentials are present in the request (value is
-     * "X-Sling-Request-Login").
-     *
+     * The request parameter causing a 401/UNAUTHORIZED status to be sent back
+     * in the {@link #authenticate(HttpServletRequest, HttpServletResponse)}
+     * method if no credentials are present in the request (value is
+     * "sling:authRequestLogin").
+     * 
      * @see #authenticate(HttpServletRequest, HttpServletResponse)
      */